@@ -1,7 +1,7 @@
 #
 # Kenozooid - dive planning and analysis toolbox.
 #
-# Copyright (C) 2009-2012 by Artur Wroblewski <wrobell@pld-linux.org>
+# Copyright (C) 2009-2013 by Artur Wroblewski <wrobell@pld-linux.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,16 +27,16 @@ import argparse
 
 from kenozooid.component import query, params, inject
 
-class CLIModule(object):
+class CLICommand(object):
     """
-    Command line module for Kenozooid.
+    Kenozooid's command.
     """
     description = ''
 
     @classmethod
     def add_arguments(self, parser):
         """
-        Add command line module arguments to command line parser.
+        Add a command arguments to command line parser.
 
         :Parameters:
          parser
@@ -45,27 +45,27 @@ class CLIModule(object):
 
     def __call__(self, args):
         """
-        Execute command line module.
+        Execute Kenozooid command.
 
         May raise ArgumentError exception to indicate wrong arguments.
 
         :Parameters:
          args
-            Command line module arguments.
+            Command arguments.
         """
 
 
 
 class ArgumentError(BaseException):
     """
-    Wrong command line module arguments.
+    Error to indicate incorrect Kenozooid command arguments.
     """
 
 
 
 class NoCommandError(BaseException):
     """
-    No command specified.
+    No Kenozooid command specified.
 
     :Attributes:
      parser
@@ -131,34 +131,32 @@ def add_commands(parser, prefix=None, title=None):
      title
         Help title of commands.
     """
-    subp = parser.add_subparsers(dest='cmd', title=title)
+    m_subp = parser.add_subparsers(dest='subcmd', title=title)
+    c_subp = None # current subparser
 
-    # find command line modules sorted by their names
-    modules = sorted(query(CLIModule), key=lambda cls: params(cls)['name'])
-    for cls in modules:
-        desc = cls.description
+    # find Kenozooid commands and sort them by their names
+    commands = sorted(query(CLICommand), key=lambda cls: params(cls)['name'])
 
+    for cls in commands:
         p = params(cls)
         name = p['name']
         master = p.get('master', False)
+        desc = cls.description
+        title = cls.title if master else None
 
-        # no prefix then simply use name as command, command shall have no
-        # spaces;
-        # if there is prefix then match command with its prefix
-        if prefix:
-            if not name.startswith(prefix) or name == prefix:
-                continue
-
-            cmd = name.rsplit(' ', 1)[1]
-        elif ' ' in name:
-            continue
+        if ' '  in name:
+            assert c_subp # no master command, no subcommand
+            cmd, subcmd = name.split()
+            p = c_subp.add_parser(subcmd, help=desc)
         else:
-            cmd = name
+            cmd, subcmd = name, name
+            p = m_subp.add_parser(subcmd, help=desc)
+            if master: # add master command
+                c_subp = p.add_subparsers(dest='subcmd', title=title)
+            else:
+                c_subp = None
 
-        p = subp.add_parser(cmd, help=desc)
-        if not master:
-            p.set_defaults(cmd=name)
-        p.set_defaults(parser=p)
+        p.set_defaults(cmd=name, parser=p)
         cls.add_arguments(p)
 
 
@@ -183,18 +181,21 @@ def add_master_command(name, title, desc):
         Command description.
     """
 
-    @inject(CLIModule, name=name, master=True)
+    @inject(CLICommand, name=name, master=True)
     class Command(object):
 
+        title = None
         description = desc
 
         @classmethod
         def add_arguments(self, parser):
-            add_commands(parser, name, title)
+            pass
 
         def __call__(self, args):
             raise NoCommandError(args.parser)
 
+    Command.title = title
+
     return Command
 
 
