@@ -1,7 +1,7 @@
 #
 # Kenozooid - dive planning and analysis toolbox.
 #
-# Copyright (C) 2009-2012 by Artur Wroblewski <wrobell@pld-linux.org>
+# Copyright (C) 2009-2013 by Artur Wroblewski <wrobell@pld-linux.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,12 +25,12 @@ import os.path
 import logging
 
 from kenozooid.component import inject
-from kenozooid.cli import CLIModule, ArgumentError, add_master_command, \
+from kenozooid.cli import CLICommand, ArgumentError, add_master_command, \
         add_uddf_input
 
 log = logging.getLogger('kenozooid.cli.da')
 
-@inject(CLIModule, name='plot')
+@inject(CLICommand, name='plot')
 class PlotProfiles(object):
     """
     Plot profiles of dives command.
@@ -125,7 +125,7 @@ class PlotProfiles(object):
 
 
 
-@inject(CLIModule, name='analyze')
+@inject(CLICommand, name='analyze')
 class Analyze(object):
     """
     Analyze dives with R script.
